var areaChangeAnimationDuration = 400;
var validAreas = ['start', 'menu', 'media', 'imprint', 'help'];
var currentArea = '';
var currentMediaType = '';
var isFullscreenMode = false;


function init() {
	initNavButtons();
	initMediaLinks();
	showArea('start');
}

function initNavButtons() {
	$('body').on('click', function() {
		hideAllMediaSelectors();
	});
	$('#iwb-footer i.icon').on('click', function(e) {
		var target = $(this).data('target');
		var mediaSelector = $(this).data('mediaselector');
		if (typeof target != 'undefined' && !$(this).hasClass('current')) {
			showArea(target);
		}
		else if (typeof mediaSelector != 'undefined' && mediaTypeList.indexOf(mediaSelector) != -1) {
			showMediaSelector(mediaSelector);
			e.stopPropagation();
		}
	});
	$('#btn-toggleFullscreen').on('click', function() {
		toggleFullscreen();
	});
}

function initMediaLinks() {
	$('div.menu-block li a').on('click', function(e) {
		var mediaUrl = $(this).data('mediaurl');
		var mediaType = $(this).data('mediatype');
		var mediaTitle = $(this).data('mediatitle');
		if (typeof mediaUrl != 'undefined' && typeof mediaType != 'undefined' && mediaTypeList.indexOf(mediaType) != -1) {
			playMedia(mediaType, mediaUrl, mediaTitle);
		}
	});
}

function hideCurrentArea(fn) {
	$('div#iwb-content div.iwbarea.' + currentArea).fadeOut(areaChangeAnimationDuration, fn);
	clearHeaderMediaName();
}

function fadeInArea(area) {
	$('div#iwb-content div.iwbarea.' + area).fadeIn(areaChangeAnimationDuration);
}

function activateCurrNavButton() {
	$('div#iwb-footer i').removeClass('current');
	if (currentArea == 'media' && currentMediaType) {
		$('div#iwb-footer i[data-mediaselector="' + currentMediaType + '"]').addClass('current');
	}
	else {
		$('div#iwb-footer i[data-target="' + currentArea + '"]').addClass('current');
	}
}

function showArea(target) {
	stopCurrentMedia();
	hideAllMediaSelectors();
	if (currentArea) {
		hideCurrentArea(function() {
			if (validAreas.indexOf(currentArea) != -1) {
				fadeInArea(target);
			}
		});
	}
	else if (validAreas.indexOf(target) != -1) {
		fadeInArea(target);
	}
	currentArea = target;
	activateCurrNavButton();
}

function hideAllMediaSelectors() {
	$('.media-selector').removeClass('active');
}

function showMediaSelector(id) {
	hideAllMediaSelectors();
	if (currentMediaType == id && $('#mediaselector-' + id).hasClass('active')) {
		//hide menu on click on same button again but do nothing else
		return;
	}
	$('#mediaselector-' + id).addClass('active');
}

function playMedia(mediaType, mediaUrl, mediaTitle) {
	stopCurrentMedia();

	if (mediaType == 301) {	//temporary as long as we still have flash
		mediaType = 500;
	}
	if (currentArea != 'media') {
		hideCurrentArea();
		currentArea = 'media';
		showArea(currentArea);
	}
	currentMediaType = mediaType;
	activateCurrNavButton();
	window.setTimeout(hideAllMediaSelectors, 100);	//w/o timeout media selector sometimes is not hidden
	
	$('div.header-objname').html(mediaTitle);

	setPlayerDivUrl(mediaType, mediaUrl);
	if (mediaType == 302) {
		$playerDiv = $('div#iwb-content div#player-' + mediaType);
		$video = $playerDiv.find('video')[0];
		$video.load();
		$video.play();
	}
	$playerDiv.addClass('active');
}

function stopCurrentMedia() {
	$('div#iwb-content div.player').removeClass('active');
	//clear previously played media
	if (currentMediaType) {
		setPlayerDivUrl(currentMediaType, '');
	}
}

function setPlayerDivUrl(mediaType, mediaUrl) {
	$playerDiv = $('div#iwb-content div#player-' + mediaType);
	if (mediaType == 100) {
		$playerDiv.find('img').attr('src', mediaUrl);
	}
	else if (mediaType == 201) {
		if (mediaUrl == '') {
			$playerDiv.find('audio')[0].pause();
		}
		$playerDiv.find('audio').attr('src', mediaUrl);
	}
	else if (mediaType == 302) {
		if (mediaUrl == '') {
			$playerDiv.find('video')[0].pause();
		}
		$playerDiv.find('source').attr('src', mediaUrl);
	}
	else if (mediaType == 402) {
		$playerDiv.find('iframe').attr('src', mediaUrl);
	}
	else if (mediaType == 500) {
		$playerDiv.find('iframe').attr('src', mediaUrl);
	}
	else if (mediaType == 610) {
		$playerDiv.find('iframe').attr('src', mediaUrl);
	}
}

function clearHeaderMediaName() {
	$('div.header-objname').html('');
}

function toggleFullscreen() {
	if (isFullscreenMode) {
		stopFullscreenMode();
	}
	else {
		startFullscreenMode();
	}
}
function startFullscreenMode() {
	var elem = document.documentElement;
	if (typeof elem.requestFullscreen == 'function') {
		elem.requestFullscreen();
	}
	else if (typeof elem.mozRequestFullScreen == 'function') {
		elem.mozRequestFullScreen();
	}
	else if (typeof elem.msRequestFullscreen == 'function') {
		elem.msRequestFullscreen();
	}
	else if (typeof elem.webkitRequestFullscreen == 'function') {
		elem.webkitRequestFullscreen();
	}
	else {
		alert('Your browser does not support full screen display.');
		return false;
	}
	$('#btn-toggleFullscreen').removeClass('start').addClass('stop');
	isFullscreenMode = true;
}

function stopFullscreenMode() {
	if (typeof document.exitFullscreen == 'function') {
		document.exitFullscreen();
	}
	else if (typeof document.mozCancelFullScreen == 'function') {
		document.mozCancelFullScreen();
	}
	else if (typeof document.msExitFullscreen == 'function') {
		document.msExitFullscreen();
	}
	else if (typeof document.webkitExitFullscreen == 'function') {
		document.webkitExitFullscreen();
	}
	$('#btn-toggleFullscreen').removeClass('stop').addClass('start');
	isFullscreenMode = false;
}
